@@ -90,17 +90,19 @@ class AmazonCaptcha(object):
     This class represents an AmazonCaptcha object.
     """
 
-    def __init__(self, img, monoweight = 1, onreturn = 'string'):
+    monoweight = 1 # Stands to define the range of color codes while monochroming. Please, do not change.
+    maximum_letter_length = 33
+    minimum_letter_length = 14
+
+    def __init__(self, img, onreturn = 'string'):
         """
         :param img: Path to an input image OR an instance of BytesIO representing this image.
-        :param monoweight: Stands to define the range of color codes while monochroming. Please, do not change.
         :param onreturn: 'string' = 'ABCDEF'
                          'dict' = {'1': 'A', '2': 'B', '3': 'C', '4': 'D', '5': 'E', '6': 'F'}
                          'raw_dict' = the same as 'dict', but it will be returned even if a captcha wasn't solved.
         """
 
         self.img = Image.open(img, 'r')
-        self.monoweight = monoweight
         self.onreturn = onreturn
         self.letters = dict()
         self.result = dict()
@@ -134,7 +136,7 @@ class AmazonCaptcha(object):
         letter_boxes = find_letter_boxes(self.img)
         letters = [self.img.crop((letter_box[0], 0, letter_box[1], self.img.height)) for letter_box in letter_boxes]
 
-        if (len(letters) == 6 and letters[0].width < 7) or (len(letters) != 6 and len(letters) != 7):
+        if (len(letters) == 6 and letters[0].width < self.minimum_letter_length) or (len(letters) != 6 and len(letters) != 7):
             return 'Error'
 
         if len(letters) == 7:
@@ -142,6 +144,7 @@ class AmazonCaptcha(object):
             del letters[0]
 
         letters = [cut_the_white(letter) for letter in letters]
+
         self.letters = {str(k): v for k, v in zip(range(1, 7), letters)}
 
     def save_letters(self):
@@ -227,7 +230,7 @@ class AmazonCaptcha(object):
         return self.result
 
     @classmethod
-    def from_webdriver(cls, driver, monoweight = 1, onreturn = 'string'):
+    def from_webdriver(cls, driver, onreturn = 'string'):
         """
         :param driver: A selenium.webdriver.* instance.
         :param monoweight: Stands to define the range of color codes while monochroming. Please, do not change.
@@ -258,6 +261,6 @@ class AmazonCaptcha(object):
         img.save(bytes_array, format='PNG')
         img_bytes_array = bytes_array.getvalue()
 
-        return cls(BytesIO(img_bytes_array), monoweight = monoweight, onreturn = onreturn)
+        return cls(BytesIO(img_bytes_array), onreturn = onreturn)
 
 #-----------------------------------------------------------------------------------------------------------------------------------------------------------
